#!/bin/bash

set -eux

# Inspired by/based on glean-early.sh
# https://opendev.org/opendev/glean/src/branch/master/glean/init/glean-early.sh

# NOTE(TheJulia): We care about iso images, and would expect lower case as a
# result. In the case of VFAT partitions, they would be upper case.

PATH=/bin:/usr/bin:/sbin:/usr/sbin
CONFIG_DRIVE_LABEL="config-2"

# Identify the number of devices
device_count=$(lsblk -o PATH,LABEL | grep $CONFIG_DRIVE_LABEL | wc -l)

# Identify if we have an a publisher id set
publisher_id=""
if grep -q "ir_pub_id" /proc/cmdline; then
    publisher_id=$(cat /proc/cmdline | sed -e 's/^.*ir_pub_id=//' -e 's/ .*$//')
fi

if [ $device_count -lt 1 ]; then
    # Nothing to do here, exit!
    exit 0
else
    # We have *something* to do here.
    if [[ "${publisher_id}" != "" ]]; then
        # We need to enumerate through the devices, and obtain the
        for device in $(lsblk -o PATH,LABEL|grep config-2|cut -f1 -d" "); do
            device_id=$(udevadm info --query=all $device | grep ID_FS_PUBLISHER_ID | sed s/^.*=// | tr '[A-Z]' '[a-z]')
            if [[ "${publisher_id}" == "${device_id}" ]]; then
                # SUCCESS! Valid device! Do it!
                echo "Device ${device} matches the ${publisher_id}. Mounting..."
                mount -t iso9660 -o ro,mode=0700 "${device}" /mnt || true
                # We've mounted the device, the world is happy.
                # Attempt to statically configure a nic in the case where we find a network_data.json
                # In a configuration drive
                NETWORK_DATA_FILE="/mnt/openstack/latest/network_data.json"

                if [ ! -f "${NETWORK_DATA_FILE}" ]; then
                  umount /mnt
                  echo "No network_data.json found, skipping network configuration"
                  exit 0
                fi

                mkdir -p /tmp/nmc/{desired,generated}
                cp ${NETWORK_DATA_FILE} /tmp/nmc/desired/_all.yaml
                umount /mnt

                nmc generate --config-dir /tmp/nmc/desired --output-dir /tmp/nmc/generated

                nmc apply --config-dir /tmp/nmc/generated

                systemctl restart NetworkManager
            else
                echo "Did not identify $device as a valid ISO for Ironic."
            fi
        done
    fi
fi

